@@ -65,7 +65,7 @@ def _duplicate_check(lib, task):
 
     found_albums = []
     cur_paths = set(i.path for i in task.items if i)
-    for album_cand in lib.albums(artist=artist):
+    for album_cand in lib.albums(library.MatchQuery('albumartist', artist)):
         if album_cand.album == album:
             # Check whether the album is identical in contents, in which
             # case it is not a duplicate (will be replaced).
@@ -83,7 +83,11 @@ def _item_duplicate_check(lib, task):
     artist, title = task.chosen_ident()
 
     found_items = []
-    for other_item in lib.items(artist=artist, title=title):
+    query = library.AndQuery((
+        library.MatchQuery('artist', artist),
+        library.MatchQuery('title', title),
+    ))
+    for other_item in lib.items(query):
         # Existing items not considered duplicates.
         if other_item.path == task.item.path:
             continue
@@ -296,7 +300,7 @@ class ImportSession(object):
 
     def resolve_duplicate(self, task):
         raise NotImplementedError
-    
+
     def choose_item(self, task):
         raise NotImplementedError
 
@@ -533,7 +537,7 @@ def read_tasks(session):
             if resume_dir:
 
                 # Either accept immediately or prompt for input to decide.
-                if _resume() == True:
+                if _resume() is True:
                     do_resume = True
                     log.warn('Resuming interrupted import of %s' % path)
                 else:
@@ -746,7 +750,9 @@ def apply_choices(session):
         # when the last item is removed.
         task.replaced_items = defaultdict(list)
         for item in items:
-            dup_items = session.lib.items(library.MatchQuery('path', item.path))
+            dup_items = session.lib.items(
+                library.MatchQuery('path', item.path)
+            )
             for dup_item in dup_items:
                 task.replaced_items[item].append(dup_item)
                 log.debug('replacing item %i: %s' %
@@ -768,13 +774,12 @@ def apply_choices(session):
 
             # Delete duplicate files that are located inside the library
             # directory.
+            task.duplicate_paths = []
             for duplicate_path in [i.path for i in duplicate_items]:
                 if session.lib.directory in util.ancestry(duplicate_path):
-                    log.debug(u'deleting replaced duplicate %s' %
-                              util.displayable_path(duplicate_path))
-                    util.remove(duplicate_path)
-                    util.prune_dirs(os.path.dirname(duplicate_path),
-                                    session.lib.directory)
+                    # Mark the path for deletion in the manipulate_files
+                    # stage.
+                    task.duplicate_paths.append(duplicate_path)
 
         # Add items -- before path changes -- to the library. We add the
         # items now (rather than at the end) so that album structures
@@ -783,9 +788,9 @@ def apply_choices(session):
             # Remove old items.
             for replaced in task.replaced_items.itervalues():
                 for item in replaced:
-                    session.lib.remove(item)
+                    item.remove()
             for item in duplicate_items:
-                session.lib.remove(item)
+                item.remove()
 
             # Add new ones.
             if task.is_album:
@@ -811,7 +816,7 @@ def plugin_stage(session, func):
 
         # Stage may modify DB, so re-load cached item data.
         for item in task.imported_items():
-            session.lib.load(item)
+            item.load()
 
 def manipulate_files(session):
     """A coroutine (pipeline stage) that performs necessary file
@@ -823,15 +828,24 @@ def manipulate_files(session):
         if task.should_skip():
             continue
 
+        # Remove duplicate files marked for deletion.
+        if task.remove_duplicates:
+            for duplicate_path in task.duplicate_paths:
+                log.debug(u'deleting replaced duplicate %s' %
+                          util.displayable_path(duplicate_path))
+                util.remove(duplicate_path)
+                util.prune_dirs(os.path.dirname(duplicate_path),
+                                session.lib.directory)
+
         # Move/copy/write files.
         items = task.imported_items()
-        task.old_paths = [item.path for item in items]  # For deletion.
+        # Save the original paths of all items for deletion and pruning
+        # in the next step (finalization).
+        task.old_paths = [item.path for item in items]
         for item in items:
             if config['import']['move']:
                 # Just move the file.
-                old_path = item.path
-                session.lib.move(item, False)
-                task.prune(old_path)
+                item.move(False)
             elif config['import']['copy']:
                 # If it's a reimport, move in-library files and copy
                 # out-of-library files. Otherwise, copy and keep track
@@ -841,16 +855,16 @@ def manipulate_files(session):
                     # This is a reimport. Move in-library files and copy
                     # out-of-library files.
                     if session.lib.directory in util.ancestry(old_path):
-                        session.lib.move(item, False)
+                        item.move(False)
                         # We moved the item, so remove the
                         # now-nonexistent file from old_paths.
                         task.old_paths.remove(old_path)
                     else:
-                        session.lib.move(item, True)
+                        item.move(True)
                 else:
                     # A normal import. Just copy files and keep track of
                     # old paths.
-                    session.lib.move(item, True)
+                    item.move(True)
 
             if config['import']['write'] and task.should_write_tags():
                 item.write()
@@ -858,7 +872,7 @@ def manipulate_files(session):
         # Save new paths.
         with session.lib.transaction():
             for item in items:
-                session.lib.store(item)
+                item.store()
 
         # Plugin event.
         plugins.send('import_task_files', session=session, task=task)
@@ -889,7 +903,7 @@ def finalize(session):
                 plugins.send('item_imported',
                              lib=session.lib, item=item)
 
-        # Finally, delete old files.
+        # When copying and deleting originals, delete old files.
         if config['import']['copy'] and config['import']['delete']:
             new_paths = [os.path.realpath(item.path) for item in items]
             for old_path in task.old_paths:
@@ -898,6 +912,12 @@ def finalize(session):
                     util.remove(syspath(old_path), False)
                     task.prune(old_path)
 
+        # When moving, prune empty directories containing the original
+        # files.
+        elif config['import']['move']:
+            for old_path in task.old_paths:
+                task.prune(old_path)
+
         # Update progress.
         if _resume():
             task.save_progress()
