@@ -139,7 +139,8 @@ def disambig_string(info):
         if info.media:
             if info.mediums > 1:
                 disambig.append(u'{0}x{1}'.format(
-                info.mediums, info.media))
+                    info.mediums, info.media
+                ))
             else:
                 disambig.append(info.media)
         if info.year:
@@ -209,7 +210,7 @@ def show_change(cur_artist, cur_album, match):
             index = medium_index = track_info.track
             medium = track_info.disc
             mediums = track_info.disctotal
-        if config['per_disc_numbering'].get(bool):
+        if config['per_disc_numbering']:
             if mediums > 1:
                 return u'{0}-{1}'.format(medium, medium_index)
             else:
@@ -235,7 +236,7 @@ def show_change(cur_artist, cur_album, match):
         print_("To:")
         show_album(artist_r, album_r)
     else:
-        print_(u"Tagging:\n    %s - %s" % (match.info.artist, match.info.album))
+        print_(u"Tagging:\n    {0.artist} - {0.album}".format(match.info))
 
     # Data URL.
     if match.info.data_url:
@@ -464,7 +465,7 @@ def choose_candidate(candidates, singleton, rec, cur_artist=None,
             print_("No matching release found for {0} tracks."
                    .format(itemcount))
             print_('For help, see: '
-                   'https://github.com/sampsyo/beets/wiki/FAQ#wiki-nomatch')
+                   'http://beets.readthedocs.org/en/latest/faq.html#nomatch')
             opts = ('Use as-is', 'as Tracks', 'Skip', 'Enter search',
                     'enter Id', 'aBort')
         sel = ui.input_options(opts)
@@ -610,8 +611,7 @@ def manual_search(singleton):
 def manual_id(singleton):
     """Input an ID, either for an album ("release") or a track ("recording").
     """
-    prompt = 'Enter %s ID:' % \
-             ('recording' if singleton else 'release')
+    prompt = u'Enter {0} ID:'.format('recording' if singleton else 'release')
     return input_(prompt).strip()
 
 class TerminalImportSession(importer.ImportSession):
@@ -894,7 +894,7 @@ def update_items(lib, query, album, move, pretend):
             if not os.path.exists(syspath(item.path)):
                 ui.print_obj(item, lib)
                 if not pretend:
-                    lib.remove(item, True)
+                    item.remove(True)
                 affected_albums.add(item.album_id)
                 continue
 
@@ -905,7 +905,7 @@ def update_items(lib, query, album, move, pretend):
                 continue
 
             # Read new data.
-            old_data = dict(item.record)
+            old_data = dict(item)
             try:
                 item.read()
             except Exception as exc:
@@ -920,12 +920,12 @@ def update_items(lib, query, album, move, pretend):
                     old_data['albumartist'] == old_data['artist'] == \
                         item.artist:
                 item.albumartist = old_data['albumartist']
-                item.dirty['albumartist'] = False
+                item._dirty.discard('albumartist')
 
             # Get and save metadata changes.
             changes = {}
             for key in library.ITEM_KEYS_META:
-                if item.dirty[key]:
+                if key in item._dirty:
                     changes[key] = old_data[key], getattr(item, key)
             if changes:
                 # Something changed.
@@ -939,16 +939,16 @@ def update_items(lib, query, album, move, pretend):
 
                 # Move the item if it's in the library.
                 if move and lib.directory in ancestry(item.path):
-                    lib.move(item)
+                    item.move()
 
-                lib.store(item)
+                item.store()
                 affected_albums.add(item.album_id)
             elif not pretend:
                 # The file's mtime was different, but there were no changes
                 # to the metadata. Store the new mtime, which is set in the
                 # call to read(), so we don't check this again in the
                 # future.
-                lib.store(item)
+                item.store()
 
         # Skip album changes while pretending.
         if pretend:
@@ -959,17 +959,18 @@ def update_items(lib, query, album, move, pretend):
             if album_id is None:  # Singletons.
                 continue
             album = lib.get_album(album_id)
-            if not album: # Empty albums have already been removed.
+            if not album:  # Empty albums have already been removed.
                 log.debug('emptied album %i' % album_id)
                 continue
-            al_items = list(album.items())
+            first_item = album.items().get()
 
             # Update album structure to reflect an item in it.
             for key in library.ALBUM_KEYS_ITEM:
-                setattr(album, key, getattr(al_items[0], key))
+                album[key] = first_item[key]
+            album.store()
 
             # Move album art (and any inconsistent items).
-            if move and lib.directory in ancestry(al_items[0].path):
+            if move and lib.directory in ancestry(first_item.path):
                 log.debug('moving album %i' % album_id)
                 album.move()
 
@@ -1014,12 +1015,8 @@ def remove_items(lib, query, album, delete):
 
     # Remove (and possibly delete) items.
     with lib.transaction():
-        if album:
-            for al in albums:
-                al.remove(delete)
-        else:
-            for item in items:
-                lib.remove(item, delete)
+        for obj in (albums if album else items):
+            obj.remove(delete)
 
 remove_cmd = ui.Subcommand('remove',
     help='remove matching items from the library', aliases=('rm',))
@@ -1099,6 +1096,8 @@ def _convert_type(key, value, album=False):
     `album` indicates whether to use album or item field definitions.
     """
     fields = library.ALBUM_FIELDS if album else library.ITEM_FIELDS
+    if key not in fields:
+        return value
     typ = [f[1] for f in fields if f[0] == key][0]
 
     if typ is bool:
@@ -1120,15 +1119,9 @@ def _convert_type(key, value, album=False):
 def modify_items(lib, mods, query, write, move, album, confirm):
     """Modifies matching items according to key=value assignments."""
     # Parse key=value specifications into a dictionary.
-    if album:
-        allowed_keys = library.ALBUM_KEYS
-    else:
-        allowed_keys = library.ITEM_KEYS_WRITABLE + ['added']
     fsets = {}
     for mod in mods:
         key, value = mod.split('=', 1)
-        if key not in allowed_keys:
-            raise ui.UserError('"%s" is not a valid field' % key)
         fsets[key] = _convert_type(key, value, album)
 
     # Get the items to modify.
@@ -1143,8 +1136,7 @@ def modify_items(lib, mods, query, write, move, album, confirm):
 
         # Show each change.
         for field, value in fsets.iteritems():
-            curval = getattr(obj, field)
-            _showdiff(field, curval, value)
+            _showdiff(field, obj.get(field), value)
 
     # Confirm.
     if confirm:
@@ -1156,20 +1148,15 @@ def modify_items(lib, mods, query, write, move, album, confirm):
     with lib.transaction():
         for obj in objs:
             for field, value in fsets.iteritems():
-                setattr(obj, field, value)
+                obj[field] = value
 
             if move:
                 cur_path = obj.item_dir() if album else obj.path
                 if lib.directory in ancestry(cur_path): # In library?
                     log.debug('moving object %s' % cur_path)
-                    if album:
-                        obj.move()
-                    else:
-                        lib.move(obj)
+                    obj.move()
 
-            # When modifying items, we have to store them to the database.
-            if not album:
-                lib.store(obj)
+            obj.store()
 
     # Apply tags if requested.
     if write:
@@ -1222,11 +1209,8 @@ def move_items(lib, dest, query, copy, album):
         old_path = obj.item_dir() if album else obj.path
         logging.debug('moving: %s' % old_path)
 
-        if album:
-            obj.move(copy, basedir=dest)
-        else:
-            lib.move(obj, copy, basedir=dest)
-            lib.store(obj)
+        obj.move(copy, basedir=dest)
+        obj.store()
 
 move_cmd = ui.Subcommand('move',
     help='move or copy items', aliases=('mv',))
