@@ -25,7 +25,8 @@ if PY3:
 else:
     exec("""
 def _reraise(typ, exc, tb):
-    raise typ, exc, tb""")
+    raise typ, exc, tb
+""")
 
 
 # Basic events used for thread scheduling.
@@ -78,6 +79,11 @@ class JoinEvent(Event):
     def __init__(self, child):
         self.child = child
 
+class KillEvent(Event):
+    """Unschedule a child thread."""
+    def __init__(self, child):
+        self.child = child
+
 class DelegationEvent(Event):
     """Suspend execution of the current thread, start a new thread and,
     once the child thread finished, return control to the parent
@@ -194,7 +200,14 @@ class ThreadException(Exception):
         _reraise(self.exc_info[0], self.exc_info[1], self.exc_info[2])
 
 SUSPENDED = Event()  # Special sentinel placeholder for suspended threads.
-        
+
+class Delegated(Event):
+    """Placeholder indicating that a thread has delegated execution to a
+    different thread.
+    """
+    def __init__(self, child):
+        self.child = child
+
 def run(root_coro):
     """Schedules a coroutine, running it to completion. This
     encapsulates the Bluelet scheduler, which the root coroutine can
@@ -260,6 +273,20 @@ def run(root_coro):
                 next_event = DelegationEvent(next_event)
             threads[coro] = next_event
 
+    def kill_thread(coro):
+        """Unschedule this thread and its (recursive) delegates.
+        """
+        # Collect all coroutines in the delegation stack.
+        coros = [coro]
+        while isinstance(threads[coro], Delegated):
+            coro = threads[coro].child
+            coros.append(coro)
+
+        # Complete each coroutine from the top to the bottom of the
+        # stack.
+        for coro in reversed(coros):
+            complete_thread(coro, None)
+
     # Continue advancing threads until root thread exits.
     exit_te = None
     while threads:
@@ -280,7 +307,7 @@ def run(root_coro):
                         advance_thread(coro, event.exc_info, True)
                         have_ready = True
                     elif isinstance(event, DelegationEvent):
-                        threads[coro] = SUSPENDED  # Suspend.
+                        threads[coro] = Delegated(event.spawned)  # Suspend.
                         threads[event.spawned] = ValueEvent(None)  # Spawn.
                         delegators[event.spawned] = coro
                         have_ready = True
@@ -292,6 +319,10 @@ def run(root_coro):
                         threads[coro] = SUSPENDED  # Suspend.
                         joiners[event.child].append(coro)
                         have_ready = True
+                    elif isinstance(event, KillEvent):
+                        threads[coro] = ValueEvent(None)
+                        kill_thread(event.child)
+                        have_ready = True
 
                 # Only start the select when nothing else is ready.
                 if not have_ready:
@@ -314,7 +345,7 @@ def run(root_coro):
                     threads[event2coro[event]] = ReturnEvent(None)
                 else:
                     advance_thread(event2coro[event], value)
-    
+
         except ThreadException as te:
             # Exception raised from inside a thread.
             event = ExceptionEvent(te.exc_info)
@@ -327,7 +358,7 @@ def run(root_coro):
                 # The thread is root-level. Raise in client code.
                 exit_te = te
                 break
-        
+
         except:
             # For instance, KeyboardInterrupt during select(). Raise
             # into root thread and terminate others.
@@ -344,12 +375,16 @@ def run(root_coro):
 
 # Sockets and their associated events.
 
+class SocketClosedError(Exception):
+    pass
+
 class Listener(object):
     """A socket wrapper object for listening sockets.
     """
     def __init__(self, host, port):
         """Create a listening socket on the given hostname and port.
         """
+        self._closed = False
         self.host = host
         self.port = port
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -362,11 +397,14 @@ class Listener(object):
         When a connection is made, the event returns a Connection
         object.
         """
+        if self._closed:
+            raise SocketClosedError()
         return AcceptEvent(self)
 
     def close(self):
         """Immediately close the listening socket. (Not an event.)
         """
+        self._closed = True
         self.sock.close()
 
 class Connection(object):
@@ -376,13 +414,18 @@ class Connection(object):
         self.sock = sock
         self.addr = addr
         self._buf = b''
+        self._closed = False
 
     def close(self):
         """Close the connection."""
+        self._closed = True
         self.sock.close()
 
     def recv(self, size):
         """Read at most size bytes of data from the socket."""
+        if self._closed:
+            raise SocketClosedError()
+
         if self._buf:
             # We already have data read previously.
             out = self._buf[:size]
@@ -395,14 +438,21 @@ class Connection(object):
         """Sends data on the socket, returning the number of bytes
         successfully sent.
         """
+        if self._closed:
+            raise SocketClosedError()
         return SendEvent(self, data)
 
     def sendall(self, data):
         """Send all of data on the socket."""
+        if self._closed:
+            raise SocketClosedError()
         return SendEvent(self, data, True)
 
     def readline(self, terminator=b"\n", bufsize=1024):
         """Reads a line (delimited by terminator) from the socket."""
+        if self._closed:
+            raise SocketClosedError()
+
         while True:
             if terminator in self._buf:
                 line, self._buf = self._buf.split(terminator, 1)
@@ -490,13 +540,13 @@ def call(coro):
         raise ValueError('%s is not a coroutine' % str(coro))
     return DelegationEvent(coro)
 
-def end(value = None):
+def end(value=None):
     """Event: ends the coroutine and returns a value to its
     delegator.
     """
     return ReturnEvent(value)
 
-def read(fd, bufsize = None):
+def read(fd, bufsize=None):
     """Event: read from a file descriptor asynchronously."""
     if bufsize is None:
         # Read all.
@@ -536,6 +586,11 @@ def join(coro):
     """
     return JoinEvent(coro)
 
+def kill(coro):
+    """Halt the execution of a different `spawn`ed thread.
+    """
+    return KillEvent(coro)
+
 
 # Convenience function for running socket servers.
 
@@ -550,7 +605,7 @@ def server(host, port, func):
             yield func(conn)
         finally:
             conn.close()
-            
+
     listener = Listener(host, port)
     try:
         while True:
