@@ -29,8 +29,8 @@ import beets
 from beets.plugins import BeetsPlugin
 import beets.ui
 from beets import vfs
-from beets import config
 from beets.util import bluelet
+from beets.library import ITEM_KEYS_WRITABLE
 
 PROTOCOL_VERSION = '0.13.0'
 BUFSIZE = 1024
@@ -751,7 +751,7 @@ class Server(BaseServer):
     # Metadata helper functions.
 
     def _item_info(self, item):
-        info_lines = [u'file: ' + self.lib.destination(item, fragment=True),
+        info_lines = [u'file: ' + item.destination(fragment=True),
                       u'Time: ' + unicode(int(item.length)),
                       u'Title: ' + item.title,
                       u'Artist: ' + item.artist,
@@ -930,12 +930,12 @@ class Server(BaseServer):
     def cmd_stats(self, conn):
         """Sends some statistics about the library."""
         with self.lib.transaction() as tx:
-            songs, totaltime = beets.library.TrueQuery().count(tx)
-
             statement = 'SELECT COUNT(DISTINCT artist), ' \
-                        'COUNT(DISTINCT album) FROM items'
-            result = tx.query(statement)[0]
-            artists, albums = result[0], result[1]
+                        'COUNT(DISTINCT album), ' \
+                        'COUNT(id), ' \
+                        'SUM(length) ' \
+                        'FROM items'
+            artists, albums, songs, totaltime = tx.query(statement)[0]
 
         yield (u'artists: ' + unicode(artists),
                u'albums: ' + unicode(albums),
@@ -997,7 +997,7 @@ class Server(BaseServer):
             for tag, value in zip(it, it):
                 if tag.lower() == u'any':
                     if any_query_type:
-                        queries.append(any_query_type(value))
+                        queries.append(any_query_type(value, ITEM_KEYS_WRITABLE, query_type))
                     else:
                         raise BPDError(ERROR_UNKNOWN, u'no such tagtype')
                 else:
@@ -1010,7 +1010,7 @@ class Server(BaseServer):
     def cmd_search(self, conn, *kv):
         """Perform a substring match for items."""
         query = self._metadata_query(beets.library.SubstringQuery,
-                                     beets.library.AnySubstringQuery,
+                                     beets.library.AnyFieldQuery,
                                      kv)
         for item in self.lib.items(query):
             yield self._item_info(item)
@@ -1045,8 +1045,11 @@ class Server(BaseServer):
         tag/value query.
         """
         _, key = self._tagtype_lookup(tag)
-        query = beets.library.MatchQuery(key, value)
-        songs, playtime = query.count(self.lib)
+        songs = 0
+        playtime = 0.0
+        for item in self.lib.items(beets.library.MatchQuery(key, value)):
+            songs += 1
+            playtime += item.length
         yield u'songs: ' + unicode(songs)
         yield u'playtime: ' + unicode(int(playtime))
 
