@@ -19,6 +19,8 @@ import os
 import threading
 from subprocess import Popen
 import tempfile
+from string import Template
+import pipes
 
 from beets.plugins import BeetsPlugin
 from beets import ui, util
@@ -30,29 +32,77 @@ DEVNULL = open(os.devnull, 'wb')
 _fs_lock = threading.Lock()
 _temp_files = []  # Keep track of temporary transcoded files for deletion.
 
+# Some convenient alternate names for formats.
+ALIASES = {
+    u'wma': u'windows media',
+    u'vorbis': u'ogg',
+}
 
-def _destination(lib, dest_dir, item, keep_new, path_formats):
+
+def _destination(dest_dir, item, keep_new, path_formats):
     """Return the path under `dest_dir` where the file should be placed
     (possibly after conversion).
     """
-    dest = lib.destination(item, basedir=dest_dir, path_formats=path_formats)
+    dest = item.destination(basedir=dest_dir, path_formats=path_formats)
     if keep_new:
         # When we're keeping the converted file, no extension munging
         # occurs.
         return dest
     else:
-        # Otherwise, replace the extension with .mp3.
-        return os.path.splitext(dest)[0] + '.mp3'
+        # Otherwise, replace the extension.
+        _, ext = get_format()
+        return os.path.splitext(dest)[0] + ext
+
+
+def get_format():
+    """Get the currently configured format command and extension.
+    """
+    format = config['convert']['format'].get(unicode).lower()
+    format = ALIASES.get(format, format)
+    format_info = config['convert']['formats'][format].get(dict)
+
+    # Convenience and backwards-compatibility shortcuts.
+    keys = config['convert'].keys()
+    if 'command' in keys:
+        format_info['command'] = config['convert']['command'].get(unicode)
+    elif 'opts' in keys:
+        # Undocumented option for backwards compatibility with < 1.3.1.
+        format_info['command'] = u'ffmpeg -i $source -y {0} $dest'.format(
+            config['convert']['opts'].get(unicode)
+        )
+    if 'extension' in keys:
+        format_info['extension'] = config['convert']['extension'].get(unicode)
+
+    try:
+        return [a.encode('utf8') for a in format_info['command'].split()], \
+                (u'.' + format_info['extension']).encode('utf8')
+    except KeyError:
+        raise ui.UserError(
+            u'convert: format {0} needs "command" and "extension" fields'
+            .format(format)
+        )
 
 
 def encode(source, dest):
-    log.info(u'Started encoding {0}'.format(util.displayable_path(source)))
+    quiet = config['convert']['quiet'].get()
 
-    opts = config['convert']['opts'].get(unicode).split(u' ')
-    encode = Popen([config['convert']['ffmpeg'].get(unicode), '-i',
-                    source, '-y'] + opts + [dest],
-                   close_fds=True, stderr=DEVNULL)
+    if not quiet:
+        log.info(u'Started encoding {0}'.format(util.displayable_path(source)))
+
+    command, _ = get_format()
+    opts = []
+    for arg in command:
+        opts.append(Template(arg).safe_substitute({
+            'source': source,
+            'dest':   dest,
+        }))
+
+    log.debug(u'convert: executing: {0}'.format(
+        u' '.join(pipes.quote(o.decode('utf8', 'ignore')) for o in opts)
+    ))
+    encode = Popen(opts, close_fds=True, stderr=DEVNULL)
     encode.wait()
+
     if encode.returncode != 0:
         # Something went wrong (probably Ctrl+C), remove temporary files
         log.info(u'Encoding {0} failed. Cleaning up...'
@@ -60,7 +110,11 @@ def encode(source, dest):
         util.remove(dest)
         util.prune_dirs(os.path.dirname(dest))
         return
-    log.info(u'Finished encoding {0}'.format(util.displayable_path(source)))
+
+    if not quiet:
+        log.info(u'Finished encoding {0}'.format(
+            util.displayable_path(source))
+        )
 
 
 def should_transcode(item):
@@ -68,13 +122,15 @@ def should_transcode(item):
     conversion (i.e., its bitrate is high or it has the wrong format).
     """
     maxbr = config['convert']['max_bitrate'].get(int)
-    return item.format != 'MP3' or item.bitrate >= 1000 * maxbr
+    format_name = config['convert']['format'].get(unicode)
+    return format_name.lower() == item.format.lower() or \
+            item.bitrate >= 1000 * maxbr
 
 
-def convert_item(lib, dest_dir, keep_new, path_formats):
+def convert_item(dest_dir, keep_new, path_formats):
     while True:
         item = yield
-        dest = _destination(lib, dest_dir, item, keep_new, path_formats)
+        dest = _destination(dest_dir, item, keep_new, path_formats)
 
         if os.path.exists(util.syspath(dest)):
             log.info(u'Skipping {0} (target file exists)'.format(
@@ -106,7 +162,8 @@ def convert_item(lib, dest_dir, keep_new, path_formats):
 
         else:
             if keep_new:
-                item.path = os.path.splitext(item.path)[0] + '.mp3'
+                _, ext = get_format()
+                item.path = os.path.splitext(item.path)[0] + ext
                 encode(dest, item.path)
             else:
                 encode(item.path, dest)
@@ -120,10 +177,10 @@ def convert_item(lib, dest_dir, keep_new, path_formats):
         # writing) to get new bitrate, duration, etc.
         if keep_new:
             item.read()
-            lib.store(item)  # Store new path and audio data.
+            item.store()  # Store new path and audio data.
 
         if config['convert']['embed']:
-            album = lib.get_album(item)
+            album = item.get_album()
             if album:
                 artpath = album.artpath
                 if artpath:
@@ -135,21 +192,24 @@ def convert_on_import(lib, item):
     library.
     """
     if should_transcode(item):
-        fd, dest = tempfile.mkstemp('.mp3')
+        _, ext = get_format()
+        fd, dest = tempfile.mkstemp(ext)
         os.close(fd)
         _temp_files.append(dest)  # Delete the transcode later.
         encode(item.path, dest)
         item.path = dest
         item.write()
         item.read()  # Load new audio information data.
-        lib.store(item)
+        item.store()
 
 
 def convert_func(lib, opts, args):
     dest = opts.dest if opts.dest is not None else \
             config['convert']['dest'].get()
+
     if not dest:
         raise ui.UserError('no convert destination set')
+
     dest = util.bytestring_path(dest)
     threads = opts.threads if opts.threads is not None else \
             config['convert']['threads'].get(int)
@@ -168,8 +228,9 @@ def convert_func(lib, opts, args):
     if opts.album:
         items = (i for a in lib.albums(ui.decargs(args)) for i in a.items())
     else:
-        items = lib.items(ui.decargs(args))
-    convert = [convert_item(lib, dest, keep_new, path_formats) for i in range(threads)]
+        items = iter(lib.items(ui.decargs(args)))
+    convert = [convert_item(dest, keep_new, path_formats)
+               for i in range(threads)]
     pipe = util.pipeline.Pipeline([items, convert])
     pipe.run_parallel()
 
@@ -180,11 +241,45 @@ class ConvertPlugin(BeetsPlugin):
         self.config.add({
             u'dest': None,
             u'threads': util.cpu_count(),
-            u'ffmpeg': u'ffmpeg',
-            u'opts': u'-aq 2',
+            u'format': u'mp3',
+            u'formats': {
+                u'aac': {
+                    u'command': u'ffmpeg -i $source -y -acodec libfaac '
+                                u'-aq 100 $dest',
+                    u'extension': u'm4a',
+                },
+                u'alac': {
+                    u'command': u'ffmpeg -i $source -y -acodec alac $dest',
+                    u'extension': u'm4a',
+                },
+                u'flac': {
+                    u'command': u'ffmpeg -i $source -y -acodec flac $dest',
+                    u'extension': u'flac',
+                },
+                u'mp3': {
+                    u'command': u'ffmpeg -i $source -y -aq 2 $dest',
+                    u'extension': u'mp3',
+                },
+                u'opus': {
+                    u'command': u'ffmpeg -i $source -y -acodec libopus -vn '
+                                u'-ab 96k $dest',
+                    u'extension': u'opus',
+                },
+                u'ogg': {
+                    u'command': u'ffmpeg -i $source -y -acodec libvorbis -vn '
+                                u'-aq 2 $dest',
+                    u'extension': u'ogg',
+                },
+                u'windows media': {
+                    u'command': u'ffmpeg -i $source -y -acodec wmav2 '
+                                u'-vn $dest',
+                    u'extension': u'wma',
+                },
+            },
             u'max_bitrate': 500,
-            u'embed': True,
             u'auto': False,
+            u'quiet': False,
+            u'embed': True,
             u'paths': {},
         })
         self.import_stages = [self.auto_convert]
