@@ -65,12 +65,19 @@ def _fetch_image(url):
 # Cover Art Archive.
 
 CAA_URL = 'http://coverartarchive.org/release/{mbid}/front-500.jpg'
+CAA_GROUP_URL = 'http://coverartarchive.org/release-group/{mbid}/front-500.jpg'
 
 def caa_art(release_id):
     """Return the Cover Art Archive URL given a MusicBrainz release ID.
     """
     return CAA_URL.format(mbid=release_id)
 
+def caa_group_art(release_group_id):
+    """Return the Cover Art Archive release group URL given a MusicBrainz
+    release group ID.
+    """
+    return CAA_GROUP_URL.format(mbid=release_group_id)
+
 
 # Art from Amazon.
 
@@ -148,10 +155,11 @@ def _source_urls(album):
     through this sequence early to avoid the cost of scraping when not
     necessary.
     """
+    # Cover Art Archive.
     if album.mb_albumid:
-        url = caa_art(album.mb_albumid)
-        if url:
-            yield url
+        yield caa_art(album.mb_albumid)
+    if album.mb_releasegroupid:
+        yield caa_group_art(album.mb_releasegroupid)
 
     # Amazon and AlbumArt.org.
     if album.asin:
@@ -208,6 +216,7 @@ def batch_fetch_art(lib, albums, force, maxwidth=None):
 
             if path:
                 album.set_art(path, False)
+                album.store()
                 message = 'found album art'
             else:
                 message = 'no art found'
@@ -266,6 +275,7 @@ class FetchArtPlugin(BeetsPlugin):
             src_removed = config['import']['delete'].get(bool) or \
                           config['import']['move'].get(bool)
             album.set_art(path, not src_removed)
+            album.store()
             if src_removed:
                 task.prune(path)
 
