@@ -1,5 +1,5 @@
 # This file is part of beets.
-# Copyright 2012, Adrian Sampson.
+# Copyright 2013, Adrian Sampson.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -22,6 +22,7 @@ from collections import defaultdict
 from beets.plugins import BeetsPlugin
 from beets import ui
 from beets import library
+from beets import config
 
 log = logging.getLogger('beets')
 
@@ -41,16 +42,14 @@ def rewriter(field, rules):
     return fieldfunc
 
 class RewritePlugin(BeetsPlugin):
-    template_fields = {}
+    def __init__(self):
+        super(RewritePlugin, self).__init__()
 
-    def configure(self, config):
-        cls = type(self)
+        self.config.add({})
 
         # Gather all the rewrite rules for each field.
         rules = defaultdict(list)
-        if not config.has_section('rewrite'):
-            return
-        for key, value in config.items('rewrite', True):
+        for key, value in self.config.items():
             try:
                 fieldname, pattern = key.split(None, 1)
             except ValueError:
@@ -68,4 +67,4 @@ class RewritePlugin(BeetsPlugin):
 
         # Replace each template field with the new rewriter function.
         for fieldname, fieldrules in rules.iteritems():
-            cls.template_fields[fieldname] = rewriter(fieldname, fieldrules)
+            self.template_fields[fieldname] = rewriter(fieldname, fieldrules)
