@@ -2,7 +2,7 @@ AUTHOR = u'Adrian Sampson'
 
 # -- General configuration -----------------------------------------------------
 
-extensions = []
+extensions = ['sphinx.ext.autodoc']
 
 #templates_path = ['_templates']
 exclude_patterns = ['_build']
@@ -12,8 +12,8 @@ master_doc = 'index'
 project = u'beets'
 copyright = u'2012, Adrian Sampson'
 
-version = '1.2'
-release = '1.2.1'
+version = '1.3'
+release = '1.3.1'
 
 pygments_style = 'sphinx'
 
