@@ -42,38 +42,41 @@ RSRC = os.path.join(os.path.dirname(__file__), 'rsrc')
 
 # Dummy item creation.
 _item_ident = 0
-def item():
+def item(lib=None):
     global _item_ident
     _item_ident += 1
-    return beets.library.Item({
-        'title':            u'the title',
-        'artist':           u'the artist',
-        'albumartist':      u'the album artist',
-        'album':            u'the album',
-        'genre':            u'the genre',
-        'composer':         u'the composer',
-        'grouping':         u'the grouping',
-        'year':             1,
-        'month':            2,
-        'day':              3,
-        'track':            4,
-        'tracktotal':       5,
-        'disc':             6,
-        'disctotal':        7,
-        'lyrics':           u'the lyrics',
-        'comments':         u'the comments',
-        'bpm':              8,
-        'comp':             True,
-        'path':             'somepath' + str(_item_ident),
-        'length':           60.0,
-        'bitrate':          128000,
-        'format':           'FLAC',
-        'mb_trackid':       'someID-1',
-        'mb_albumid':       'someID-2',
-        'mb_artistid':      'someID-3',
-        'mb_albumartistid': 'someID-4',
-        'album_id':         None,
-    })
+    i = beets.library.Item(
+        title =            u'the title',
+        artist =           u'the artist',
+        albumartist =      u'the album artist',
+        album =            u'the album',
+        genre =            u'the genre',
+        composer =         u'the composer',
+        grouping =         u'the grouping',
+        year =             1,
+        month =            2,
+        day =              3,
+        track =            4,
+        tracktotal =       5,
+        disc =             6,
+        disctotal =        7,
+        lyrics =           u'the lyrics',
+        comments =         u'the comments',
+        bpm =              8,
+        comp =             True,
+        path =             'somepath' + str(_item_ident),
+        length =           60.0,
+        bitrate =          128000,
+        format =           'FLAC',
+        mb_trackid =       'someID-1',
+        mb_albumid =       'someID-2',
+        mb_artistid =      'someID-3',
+        mb_albumartistid = 'someID-4',
+        album_id =         None,
+    )
+    if lib:
+        lib.add(i)
+    return i
 
 # Dummy import session.
 def import_session(lib=None, logfile=None, paths=[], query=[], cli=False):
@@ -123,6 +126,16 @@ class TestCase(unittest.TestCase):
         self.assertFalse(os.path.exists(path),
                         'file exists: %s' % path)
 
+class LibTestCase(TestCase):
+    """A test case that includes an in-memory library object (`lib`) and
+    an item added to the library (`i`).
+    """
+    def setUp(self):
+        super(LibTestCase, self).setUp()
+        self.lib = beets.library.Library(':memory:')
+        self.i = item(self.lib)
+
+
 
 
 # Mock timing.
