@@ -33,73 +33,53 @@ from beets import config
 
 TEMP_LIB = os.path.join(_common.RSRC, 'test_copy.blb')
 
-def lib():
-    shutil.copy(os.path.join(_common.RSRC, 'test.blb'), TEMP_LIB)
-    return beets.library.Library(TEMP_LIB)
-def remove_lib():
-    if os.path.exists(TEMP_LIB):
-        os.unlink(TEMP_LIB)
-def boracay(l):
-    return beets.library.Item(
-        l._connection().execute('select * from items where id=3').fetchone()
-    )
+# Shortcut to path normalization.
 np = util.normpath
 
-class LoadTest(unittest.TestCase):
-    def setUp(self):
-        self.lib = lib()
-        self.i = boracay(self.lib)
-    def tearDown(self):
-        self.lib._connection().close()
-        remove_lib()
 
+class LoadTest(_common.LibTestCase):
     def test_load_restores_data_from_db(self):
         original_title = self.i.title
         self.i.title = 'something'
-        self.lib.load(self.i)
+        self.i.load()
         self.assertEqual(original_title, self.i.title)
 
     def test_load_clears_dirty_flags(self):
         self.i.artist = 'something'
-        self.lib.load(self.i)
-        self.assertTrue(not self.i.dirty['artist'])
+        self.assertTrue('artist' in self.i._dirty)
+        self.i.load()
+        self.assertTrue('artist' not in self.i._dirty)
 
-class StoreTest(unittest.TestCase):
-    def setUp(self):
-        self.lib = lib()
-        self.i = boracay(self.lib)
-    def tearDown(self):
-        self.lib._connection().close()
-        remove_lib()
 
+class StoreTest(_common.LibTestCase):
     def test_store_changes_database_value(self):
         self.i.year = 1987
-        self.lib.store(self.i)
+        self.i.store()
         new_year = self.lib._connection().execute(
             'select year from items where '
-            'title="Boracay"').fetchone()['year']
+            'title="the title"').fetchone()['year']
         self.assertEqual(new_year, 1987)
 
     def test_store_only_writes_dirty_fields(self):
         original_genre = self.i.genre
-        self.i.record['genre'] = 'beatboxing' # change value w/o dirtying
-        self.lib.store(self.i)
+        self.i._values_fixed['genre'] = 'beatboxing' # change w/o dirtying
+        self.i.store()
         new_genre = self.lib._connection().execute(
             'select genre from items where '
-            'title="Boracay"').fetchone()['genre']
+            'title="the title"').fetchone()['genre']
         self.assertEqual(new_genre, original_genre)
 
     def test_store_clears_dirty_flags(self):
         self.i.composer = 'tvp'
-        self.lib.store(self.i)
-        self.assertTrue(not self.i.dirty['composer'])
+        self.i.store()
+        self.assertTrue('composer' not in self.i._dirty)
 
-class AddTest(unittest.TestCase):
+
+class AddTest(_common.TestCase):
     def setUp(self):
+        super(AddTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
         self.i = item()
-    def tearDown(self):
-        self.lib._connection().close()
 
     def test_item_add_inserts_row(self):
         self.lib.add(self.i)
@@ -116,21 +96,17 @@ class AddTest(unittest.TestCase):
             'where composer="the composer"').fetchone()['grouping']
         self.assertEqual(new_grouping, self.i.grouping)
 
-class RemoveTest(unittest.TestCase):
-    def setUp(self):
-        self.lib = lib()
-        self.i = boracay(self.lib)
-    def tearDown(self):
-        self.lib._connection().close()
-        remove_lib()
 
+class RemoveTest(_common.LibTestCase):
     def test_remove_deletes_from_db(self):
-        self.lib.remove(self.i)
-        c = self.lib._connection().execute('select * from items where id=3')
+        self.i.remove()
+        c = self.lib._connection().execute('select * from items')
         self.assertEqual(c.fetchone(), None)
 
-class GetSetTest(unittest.TestCase):
+
+class GetSetTest(_common.TestCase):
     def setUp(self):
+        super(GetSetTest, self).setUp()
         self.i = item()
 
     def test_set_changes_value(self):
@@ -139,20 +115,21 @@ class GetSetTest(unittest.TestCase):
 
     def test_set_sets_dirty_flag(self):
         self.i.comp = not self.i.comp
-        self.assertTrue(self.i.dirty['comp'])
+        self.assertTrue('comp' in self.i._dirty)
 
     def test_set_does_not_dirty_if_value_unchanged(self):
         self.i.title = self.i.title
-        self.assertTrue(not self.i.dirty['title'])
+        self.assertTrue('title' not in self.i._dirty)
 
     def test_invalid_field_raises_attributeerror(self):
         self.assertRaises(AttributeError, getattr, self.i, 'xyzzy')
 
-class DestinationTest(unittest.TestCase):
+
+class DestinationTest(_common.TestCase):
     def setUp(self):
         super(DestinationTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
-        self.i = item()
+        self.i = item(self.lib)
     def tearDown(self):
         super(DestinationTest, self).tearDown()
         self.lib._connection().close()
@@ -160,12 +137,12 @@ class DestinationTest(unittest.TestCase):
     def test_directory_works_with_trailing_slash(self):
         self.lib.directory = 'one/'
         self.lib.path_formats = [('default', 'two')]
-        self.assertEqual(self.lib.destination(self.i), np('one/two'))
+        self.assertEqual(self.i.destination(), np('one/two'))
 
     def test_directory_works_without_trailing_slash(self):
         self.lib.directory = 'one'
         self.lib.path_formats = [('default', 'two')]
-        self.assertEqual(self.lib.destination(self.i), np('one/two'))
+        self.assertEqual(self.i.destination(), np('one/two'))
 
     def test_destination_substitues_metadata_values(self):
         self.lib.directory = 'base'
@@ -173,21 +150,21 @@ class DestinationTest(unittest.TestCase):
         self.i.title = 'three'
         self.i.artist = 'two'
         self.i.album = 'one'
-        self.assertEqual(self.lib.destination(self.i),
+        self.assertEqual(self.i.destination(),
                          np('base/one/two three'))
 
     def test_destination_preserves_extension(self):
         self.lib.directory = 'base'
         self.lib.path_formats = [('default', '$title')]
         self.i.path = 'hey.audioformat'
-        self.assertEqual(self.lib.destination(self.i),
+        self.assertEqual(self.i.destination(),
                          np('base/the title.audioformat'))
 
     def test_lower_case_extension(self):
         self.lib.directory = 'base'
         self.lib.path_formats = [('default', '$title')]
         self.i.path = 'hey.MP3'
-        self.assertEqual(self.lib.destination(self.i),
+        self.assertEqual(self.i.destination(),
                          np('base/the title.mp3'))
 
     def test_destination_pads_some_indices(self):
@@ -199,7 +176,7 @@ class DestinationTest(unittest.TestCase):
         self.i.disc = 3
         self.i.disctotal = 4
         self.i.bpm = 5
-        self.assertEqual(self.lib.destination(self.i),
+        self.assertEqual(self.i.destination(),
                          np('base/01 02 03 04 5'))
 
     def test_destination_pads_date_values(self):
@@ -208,43 +185,43 @@ class DestinationTest(unittest.TestCase):
         self.i.year = 1
         self.i.month = 2
         self.i.day = 3
-        self.assertEqual(self.lib.destination(self.i),
+        self.assertEqual(self.i.destination(),
                          np('base/0001-02-03'))
 
     def test_destination_escapes_slashes(self):
         self.i.album = 'one/two'
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         self.assertTrue('one' in dest)
         self.assertTrue('two' in dest)
         self.assertFalse('one/two' in dest)
 
     def test_destination_escapes_leading_dot(self):
         self.i.album = '.something'
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         self.assertTrue('something' in dest)
         self.assertFalse('/.' in dest)
 
     def test_destination_preserves_legitimate_slashes(self):
         self.i.artist = 'one'
         self.i.album = 'two'
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         self.assertTrue(os.path.join('one', 'two') in dest)
 
     def test_destination_long_names_truncated(self):
         self.i.title = 'X'*300
         self.i.artist = 'Y'*300
-        for c in self.lib.destination(self.i).split(os.path.sep):
+        for c in self.i.destination().split(os.path.sep):
             self.assertTrue(len(c) <= 255)
 
     def test_destination_long_names_keep_extension(self):
         self.i.title = 'X'*300
         self.i.path = 'something.extn'
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         self.assertEqual(dest[-5:], '.extn')
 
     def test_distination_windows_removes_both_separators(self):
         self.i.title = 'one \\ two / three.mp3'
-        p = self.lib.destination(self.i, ntpath)
+        p = self.i.destination(pathmod=ntpath)
         self.assertFalse('one \\ two' in p)
         self.assertFalse('one / two' in p)
         self.assertFalse('two \\ three' in p)
@@ -270,7 +247,7 @@ class DestinationTest(unittest.TestCase):
 
     def test_path_with_format(self):
         self.lib.path_formats = [('default', '$artist/$album ($format)')]
-        p = self.lib.destination(self.i)
+        p = self.i.destination()
         self.assert_('(FLAC)' in p)
 
     def test_heterogeneous_album_gets_single_directory(self):
@@ -278,7 +255,7 @@ class DestinationTest(unittest.TestCase):
         self.lib.add_album([i1, i2])
         i1.year, i2.year = 2009, 2010
         self.lib.path_formats = [('default', '$album ($year)/$track $title')]
-        dest1, dest2 = self.lib.destination(i1), self.lib.destination(i2)
+        dest1, dest2 = i1.destination(), i2.destination()
         self.assertEqual(os.path.dirname(dest1), os.path.dirname(dest2))
 
     def test_default_path_for_non_compilations(self):
@@ -287,20 +264,20 @@ class DestinationTest(unittest.TestCase):
         self.lib.directory = 'one'
         self.lib.path_formats = [('default', 'two'),
                                  ('comp:true', 'three')]
-        self.assertEqual(self.lib.destination(self.i), np('one/two'))
+        self.assertEqual(self.i.destination(), np('one/two'))
 
     def test_singleton_path(self):
-        i = item()
+        i = item(self.lib)
         self.lib.directory = 'one'
         self.lib.path_formats = [
             ('default', 'two'),
             ('singleton:true', 'four'),
             ('comp:true', 'three'),
         ]
-        self.assertEqual(self.lib.destination(i), np('one/four'))
+        self.assertEqual(i.destination(), np('one/four'))
 
     def test_comp_before_singleton_path(self):
-        i = item()
+        i = item(self.lib)
         i.comp = True
         self.lib.directory = 'one'
         self.lib.path_formats = [
@@ -308,7 +285,7 @@ class DestinationTest(unittest.TestCase):
             ('comp:true', 'three'),
             ('singleton:true', 'four'),
         ]
-        self.assertEqual(self.lib.destination(i), np('one/three'))
+        self.assertEqual(i.destination(), np('one/three'))
 
     def test_comp_path(self):
         self.i.comp = True
@@ -318,7 +295,7 @@ class DestinationTest(unittest.TestCase):
             ('default', 'two'),
             ('comp:true', 'three'),
         ]
-        self.assertEqual(self.lib.destination(self.i), np('one/three'))
+        self.assertEqual(self.i.destination(), np('one/three'))
 
     def test_albumtype_query_path(self):
         self.i.comp = True
@@ -330,7 +307,7 @@ class DestinationTest(unittest.TestCase):
             ('albumtype:sometype', 'four'),
             ('comp:true', 'three'),
         ]
-        self.assertEqual(self.lib.destination(self.i), np('one/four'))
+        self.assertEqual(self.i.destination(), np('one/four'))
 
     def test_albumtype_path_fallback_to_comp(self):
         self.i.comp = True
@@ -342,7 +319,7 @@ class DestinationTest(unittest.TestCase):
             ('albumtype:anothertype', 'four'),
             ('comp:true', 'three'),
         ]
-        self.assertEqual(self.lib.destination(self.i), np('one/three'))
+        self.assertEqual(self.i.destination(), np('one/three'))
 
     def test_sanitize_windows_replaces_trailing_space(self):
         p = util.sanitize_path(u'one/two /three', ntpath)
@@ -378,28 +355,28 @@ class DestinationTest(unittest.TestCase):
         self.i.artist = ''
         self.i.albumartist = 'something'
         self.lib.path_formats = [('default', '$artist')]
-        p = self.lib.destination(self.i)
+        p = self.i.destination()
         self.assertEqual(p.rsplit(os.path.sep, 1)[1], 'something')
 
     def test_albumartist_falls_back_to_artist(self):
         self.i.artist = 'trackartist'
         self.i.albumartist = ''
         self.lib.path_formats = [('default', '$albumartist')]
-        p = self.lib.destination(self.i)
+        p = self.i.destination()
         self.assertEqual(p.rsplit(os.path.sep, 1)[1], 'trackartist')
 
     def test_artist_overrides_albumartist(self):
         self.i.artist = 'theartist'
         self.i.albumartist = 'something'
         self.lib.path_formats = [('default', '$artist')]
-        p = self.lib.destination(self.i)
+        p = self.i.destination()
         self.assertEqual(p.rsplit(os.path.sep, 1)[1], 'theartist')
 
     def test_albumartist_overrides_artist(self):
         self.i.artist = 'theartist'
         self.i.albumartist = 'something'
         self.lib.path_formats = [('default', '$albumartist')]
-        p = self.lib.destination(self.i)
+        p = self.i.destination()
         self.assertEqual(p.rsplit(os.path.sep, 1)[1], 'something')
 
     def test_sanitize_path_works_on_empty_string(self):
@@ -421,13 +398,13 @@ class DestinationTest(unittest.TestCase):
     def test_unicode_normalized_nfd_on_mac(self):
         instr = unicodedata.normalize('NFC', u'caf\xe9')
         self.lib.path_formats = [('default', instr)]
-        dest = self.lib.destination(self.i, platform='darwin', fragment=True)
+        dest = self.i.destination(platform='darwin', fragment=True)
         self.assertEqual(dest, unicodedata.normalize('NFD', instr))
 
     def test_unicode_normalized_nfc_on_linux(self):
         instr = unicodedata.normalize('NFD', u'caf\xe9')
         self.lib.path_formats = [('default', instr)]
-        dest = self.lib.destination(self.i, platform='linux2', fragment=True)
+        dest = self.i.destination(platform='linux2', fragment=True)
         self.assertEqual(dest, unicodedata.normalize('NFC', instr))
 
     def test_non_mbcs_characters_on_windows(self):
@@ -436,7 +413,7 @@ class DestinationTest(unittest.TestCase):
         try:
             self.i.title = u'h\u0259d'
             self.lib.path_formats = [('default', '$title')]
-            p = self.lib.destination(self.i)
+            p = self.i.destination()
             self.assertFalse('?' in p)
             # We use UTF-8 to encode Windows paths now.
             self.assertTrue(u'h\u0259d'.encode('utf8') in p)
@@ -446,9 +423,10 @@ class DestinationTest(unittest.TestCase):
     def test_unicode_extension_in_fragment(self):
         self.lib.path_formats = [('default', u'foo')]
         self.i.path = util.bytestring_path(u'bar.caf\xe9')
-        dest = self.lib.destination(self.i, platform='linux2', fragment=True)
+        dest = self.i.destination(platform='linux2', fragment=True)
         self.assertEqual(dest, u'foo.caf\xe9')
 
+
 class PathFormattingMixin(object):
     """Utilities for testing path formatting."""
     def _setf(self, fmt):
@@ -456,16 +434,18 @@ class PathFormattingMixin(object):
     def _assert_dest(self, dest, i=None):
         if i is None:
             i = self.i
-        self.assertEqual(self.lib.destination(i, pathmod=posixpath),
-                         dest)
+        self.assertEqual(i.destination(pathmod=posixpath), dest)
 
-class DestinationFunctionTest(unittest.TestCase, PathFormattingMixin):
+
+class DestinationFunctionTest(_common.TestCase, PathFormattingMixin):
     def setUp(self):
+        super(DestinationFunctionTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
         self.lib.directory = '/base'
         self.lib.path_formats = [('default', u'path')]
-        self.i = item()
+        self.i = item(self.lib)
     def tearDown(self):
+        super(DestinationFunctionTest, self).tearDown()
         self.lib._connection().close()
 
     def test_upper_case_literal(self):
@@ -508,8 +488,10 @@ class DestinationFunctionTest(unittest.TestCase, PathFormattingMixin):
         self._setf(u'%foo{bar}')
         self._assert_dest('/base/%foo{bar}')
 
-class DisambiguationTest(unittest.TestCase, PathFormattingMixin):
+
+class DisambiguationTest(_common.TestCase, PathFormattingMixin):
     def setUp(self):
+        super(DisambiguationTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
         self.lib.directory = '/base'
         self.lib.path_formats = [('default', u'path')]
@@ -525,6 +507,7 @@ class DisambiguationTest(unittest.TestCase, PathFormattingMixin):
         self._setf(u'foo%aunique{albumartist album,year}/$title')
 
     def tearDown(self):
+        super(DisambiguationTest, self).tearDown()
         self.lib._connection().close()
 
     def test_unique_expands_to_disambiguating_year(self):
@@ -533,21 +516,21 @@ class DisambiguationTest(unittest.TestCase, PathFormattingMixin):
     def test_unique_with_default_arguments_uses_albumtype(self):
         album2 = self.lib.get_album(self.i1)
         album2.albumtype = 'bar'
-        self.lib._connection().commit()
+        album2.store()
         self._setf(u'foo%aunique{}/$title')
         self._assert_dest('/base/foo [bar]/the title', self.i1)
 
     def test_unique_expands_to_nothing_for_distinct_albums(self):
         album2 = self.lib.get_album(self.i2)
         album2.album = 'different album'
-        self.lib._connection().commit()
+        album2.store()
 
         self._assert_dest('/base/foo/the title', self.i1)
 
     def test_use_fallback_numbers_when_identical(self):
         album2 = self.lib.get_album(self.i2)
         album2.year = 2001
-        self.lib._connection().commit()
+        album2.store()
 
         self._assert_dest('/base/foo 1/the title', self.i1)
         self._assert_dest('/base/foo 2/the title', self.i2)
@@ -561,10 +544,13 @@ class DisambiguationTest(unittest.TestCase, PathFormattingMixin):
         album2.year = 2001
         album1 = self.lib.get_album(self.i1)
         album1.albumtype = 'foo/bar'
+        album2.store()
+        album1.store()
         self._setf(u'foo%aunique{albumartist album,albumtype}/$title')
         self._assert_dest('/base/foo [foo_bar]/the title', self.i1)
 
-class PathConversionTest(unittest.TestCase):
+
+class PathConversionTest(_common.TestCase):
     def test_syspath_windows_format(self):
         path = ntpath.join('a', 'b', 'c')
         outpath = util.syspath(path, pathmod=ntpath)
@@ -594,7 +580,8 @@ class PathConversionTest(unittest.TestCase):
         outpath = self._windows_bytestring_path(path)
         self.assertEqual(outpath, u'C:\\caf\xe9'.encode('utf8'))
 
-class PluginDestinationTest(unittest.TestCase):
+
+class PluginDestinationTest(_common.TestCase):
     # Mock the plugins.template_values(item) function.
     def _template_values(self, item):
         return self._tv_map
@@ -607,13 +594,13 @@ class PluginDestinationTest(unittest.TestCase):
         self.lib = beets.library.Library(':memory:')
         self.lib.directory = '/base'
         self.lib.path_formats = [('default', u'$artist $foo')]
-        self.i = item()
+        self.i = item(self.lib)
     def tearDown(self):
         super(PluginDestinationTest, self).tearDown()
         plugins.template_values = self.old_template_values
 
     def _assert_dest(self, dest):
-        self.assertEqual(self.lib.destination(self.i, pathmod=posixpath),
+        self.assertEqual(self.i.destination(pathmod=posixpath),
                          '/base/' + dest)
 
     def test_undefined_value_not_substituted(self):
@@ -637,11 +624,14 @@ class PluginDestinationTest(unittest.TestCase):
         }
         self._assert_dest('the artist bar_baz')
 
-class MigrationTest(unittest.TestCase):
+
+class MigrationTest(_common.TestCase):
     """Tests the ability to change the database schema between
     versions.
     """
     def setUp(self):
+        super(MigrationTest, self).setUp()
+
         # Three different "schema versions".
         self.older_fields = [('field_one', int)]
         self.old_fields = self.older_fields + [('field_two', int)]
@@ -660,6 +650,7 @@ class MigrationTest(unittest.TestCase):
         del old_lib
 
     def tearDown(self):
+        super(MigrationTest, self).tearDown()
         os.unlink(self.libfile)
 
     def test_open_with_same_fields_leaves_untouched(self):
@@ -741,8 +732,10 @@ class MigrationTest(unittest.TestCase):
         album = c.fetchone()
         self.assertEqual(album['albumartist'], 'theartist')
 
-class AlbumInfoTest(unittest.TestCase):
+
+class AlbumInfoTest(_common.TestCase):
     def setUp(self):
+        super(AlbumInfoTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
         self.i = item()
         self.lib.add_album((self.i,))
@@ -757,12 +750,12 @@ class AlbumInfoTest(unittest.TestCase):
     def test_albuminfo_stores_art(self):
         ai = self.lib.get_album(self.i)
         ai.artpath = '/my/great/art'
+        ai.store()
         new_ai = self.lib.get_album(self.i)
         self.assertEqual(new_ai.artpath, '/my/great/art')
 
     def test_albuminfo_for_two_items_doesnt_duplicate_row(self):
-        i2 = item()
-        self.lib.add(i2)
+        i2 = item(self.lib)
         self.lib.get_album(self.i)
         self.lib.get_album(i2)
 
@@ -795,20 +788,23 @@ class AlbumInfoTest(unittest.TestCase):
     def test_albuminfo_changes_affect_items(self):
         ai = self.lib.get_album(self.i)
         ai.album = 'myNewAlbum'
-        i = self.lib.items().next()
+        ai.store()
+        i = self.lib.items()[0]
         self.assertEqual(i.album, 'myNewAlbum')
 
     def test_albuminfo_change_albumartist_changes_items(self):
         ai = self.lib.get_album(self.i)
         ai.albumartist = 'myNewArtist'
-        i = self.lib.items().next()
+        ai.store()
+        i = self.lib.items()[0]
         self.assertEqual(i.albumartist, 'myNewArtist')
         self.assertNotEqual(i.artist, 'myNewArtist')
 
     def test_albuminfo_change_artist_does_not_change_items(self):
         ai = self.lib.get_album(self.i)
         ai.artist = 'myNewArtist'
-        i = self.lib.items().next()
+        ai.store()
+        i = self.lib.items()[0]
         self.assertNotEqual(i.artist, 'myNewArtist')
 
     def test_albuminfo_remove_removes_items(self):
@@ -821,17 +817,9 @@ class AlbumInfoTest(unittest.TestCase):
 
     def test_removing_last_item_removes_album(self):
         self.assertEqual(len(self.lib.albums()), 1)
-        self.lib.remove(self.i)
+        self.i.remove()
         self.assertEqual(len(self.lib.albums()), 0)
 
-class BaseAlbumTest(_common.TestCase):
-    def test_field_access(self):
-        album = beets.library.BaseAlbum(None, {'fld1':'foo'})
-        self.assertEqual(album.fld1, 'foo')
-
-    def test_field_access_unset_values(self):
-        album = beets.library.BaseAlbum(None, {})
-        self.assertRaises(AttributeError, getattr, album, 'field')
 
 class ArtDestinationTest(_common.TestCase):
     def setUp(self):
@@ -841,8 +829,8 @@ class ArtDestinationTest(_common.TestCase):
         self.lib = beets.library.Library(
             ':memory:', replacements=[(re.compile(u'X'), u'Y')]
         )
-        self.i = item()
-        self.i.path = self.lib.destination(self.i)
+        self.i = item(self.lib)
+        self.i.path = self.i.destination()
         self.ai = self.lib.add_album((self.i,))
 
     def test_art_filename_respects_setting(self):
@@ -851,7 +839,7 @@ class ArtDestinationTest(_common.TestCase):
 
     def test_art_path_in_item_dir(self):
         art = self.ai.art_destination('something.jpg')
-        track = self.lib.destination(self.i)
+        track = self.i.destination()
         self.assertEqual(os.path.dirname(art), os.path.dirname(track))
 
     def test_art_path_sanitized(self):
@@ -859,12 +847,12 @@ class ArtDestinationTest(_common.TestCase):
         art = self.ai.art_destination('something.jpg')
         self.assert_('artYimage' in art)
 
+
 class PathStringTest(_common.TestCase):
     def setUp(self):
         super(PathStringTest, self).setUp()
         self.lib = beets.library.Library(':memory:')
-        self.i = item()
-        self.lib.add(self.i)
+        self.i = item(self.lib)
 
     def test_item_path_is_bytestring(self):
         self.assert_(isinstance(self.i.path, str))
@@ -887,12 +875,12 @@ class PathStringTest(_common.TestCase):
     def test_special_chars_preserved_in_database(self):
         path = 'b\xe1r'
         self.i.path = path
-        self.lib.store(self.i)
+        self.i.store()
         i = list(self.lib.items())[0]
         self.assertEqual(i.path, path)
 
     def test_special_char_path_added_to_database(self):
-        self.lib.remove(self.i)
+        self.i.remove()
         path = 'b\xe1r'
         i = item()
         i.path = path
@@ -902,7 +890,7 @@ class PathStringTest(_common.TestCase):
 
     def test_destination_returns_bytestring(self):
         self.i.artist = u'b\xe1r'
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         self.assert_(isinstance(dest, str))
 
     def test_art_destination_returns_bytestring(self):
@@ -912,9 +900,10 @@ class PathStringTest(_common.TestCase):
         self.assert_(isinstance(dest, str))
 
     def test_artpath_stores_special_chars(self):
-        path = 'b\xe1r'
+        path = b'b\xe1r'
         alb = self.lib.add_album([self.i])
         alb.artpath = path
+        alb.store()
         alb = self.lib.get_album(self.i)
         self.assertEqual(path, alb.artpath)
 
@@ -942,6 +931,7 @@ class PathStringTest(_common.TestCase):
         alb = self.lib.get_album(alb.id)
         self.assert_(isinstance(alb.artpath, str))
 
+
 class PathTruncationTest(_common.TestCase):
     def test_truncate_bytestring(self):
         p = util.truncate_path('abcde/fgh', posixpath, 4)
@@ -955,6 +945,7 @@ class PathTruncationTest(_common.TestCase):
         p = util.truncate_path(u'abcde/fgh.ext', posixpath, 5)
         self.assertEqual(p, u'abcde/f.ext')
 
+
 class MtimeTest(_common.TestCase):
     def setUp(self):
         super(MtimeTest, self).setUp()
@@ -989,6 +980,7 @@ class MtimeTest(_common.TestCase):
         self.i.read()
         self.assertGreaterEqual(self.i.mtime, self._mtime())
 
+
 class ImportTimeTest(_common.TestCase):
     def setUp(self):
         super(ImportTimeTest, self).setUp()
@@ -1001,12 +993,13 @@ class ImportTimeTest(_common.TestCase):
         self.assertGreater(self.track.added, 0)
 
     def test_atime_for_singleton(self):
-        self.singleton = item()
-        self.lib.add(self.singleton)
+        self.singleton = item(self.lib)
         self.assertGreater(self.singleton.added, 0)
 
+
 def suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
 
+
 if __name__ == '__main__':
     unittest.main(defaultTest='suite')
