@@ -52,49 +52,49 @@ class MoveTest(_common.TestCase):
         self.otherdir = join(self.temp_dir, 'testotherdir')
 
     def test_move_arrives(self):
-        self.lib.move(self.i)
+        self.i.move()
         self.assertExists(self.dest)
 
     def test_move_to_custom_dir(self):
-        self.lib.move(self.i, basedir=self.otherdir)
+        self.i.move(basedir=self.otherdir)
         self.assertExists(join(self.otherdir, 'one', 'two', 'three.mp3'))
 
     def test_move_departs(self):
-        self.lib.move(self.i)
+        self.i.move()
         self.assertNotExists(self.path)
 
     def test_move_in_lib_prunes_empty_dir(self):
-        self.lib.move(self.i)
+        self.i.move()
         old_path = self.i.path
         self.assertExists(old_path)
 
         self.i.artist = 'newArtist'
-        self.lib.move(self.i)
+        self.i.move()
         self.assertNotExists(old_path)
         self.assertNotExists(os.path.dirname(old_path))
 
     def test_copy_arrives(self):
-        self.lib.move(self.i, copy=True)
+        self.i.move(copy=True)
         self.assertExists(self.dest)
 
     def test_copy_does_not_depart(self):
-        self.lib.move(self.i, copy=True)
+        self.i.move(copy=True)
         self.assertExists(self.path)
 
     def test_move_changes_path(self):
-        self.lib.move(self.i)
+        self.i.move()
         self.assertEqual(self.i.path, util.normpath(self.dest))
 
     def test_copy_already_at_destination(self):
-        self.lib.move(self.i)
+        self.i.move()
         old_path = self.i.path
-        self.lib.move(self.i, copy=True)
+        self.i.move(copy=True)
         self.assertEqual(self.i.path, old_path)
 
     def test_move_already_at_destination(self):
-        self.lib.move(self.i)
+        self.i.move()
         old_path = self.i.path
-        self.lib.move(self.i, copy=False)
+        self.i.move(copy=False)
         self.assertEqual(self.i.path, old_path)
 
     def test_read_only_file_copied_writable(self):
@@ -102,7 +102,7 @@ class MoveTest(_common.TestCase):
         os.chmod(self.path, 0444)
 
         try:
-            self.lib.move(self.i, copy=True)
+            self.i.move(copy=True)
             self.assertTrue(os.access(self.i.path, os.W_OK))
         finally:
             # Make everything writable so it can be cleaned up.
@@ -111,11 +111,11 @@ class MoveTest(_common.TestCase):
 
     def test_move_avoids_collision_with_existing_file(self):
         # Make a conflicting file at the destination.
-        dest = self.lib.destination(self.i)
+        dest = self.i.destination()
         os.makedirs(os.path.dirname(dest))
         touch(dest)
 
-        self.lib.move(self.i)
+        self.i.move()
         self.assertNotEqual(self.i.path, dest)
         self.assertEqual(os.path.dirname(self.i.path),
                          os.path.dirname(dest))
@@ -157,9 +157,9 @@ class AlbumFileTest(_common.TestCase):
             [('default', join('$albumartist', '$album', '$title'))]
         self.libdir = os.path.join(self.temp_dir, 'testlibdir')
         self.lib.directory = self.libdir
-        self.i = item()
+        self.i = item(self.lib)
         # Make a file for the item.
-        self.i.path = self.lib.destination(self.i)
+        self.i.path = self.i.destination()
         util.mkdirall(self.i.path)
         touch(self.i.path)
         # Make an album.
@@ -170,7 +170,8 @@ class AlbumFileTest(_common.TestCase):
     def test_albuminfo_move_changes_paths(self):
         self.ai.album = 'newAlbumName'
         self.ai.move()
-        self.lib.load(self.i)
+        self.ai.store()
+        self.i.load()
 
         self.assert_('newAlbumName' in self.i.path)
 
@@ -178,7 +179,8 @@ class AlbumFileTest(_common.TestCase):
         oldpath = self.i.path
         self.ai.album = 'newAlbumName'
         self.ai.move()
-        self.lib.load(self.i)
+        self.ai.store()
+        self.i.load()
 
         self.assertFalse(os.path.exists(oldpath))
         self.assertTrue(os.path.exists(self.i.path))
@@ -187,14 +189,16 @@ class AlbumFileTest(_common.TestCase):
         oldpath = self.i.path
         self.ai.album = 'newAlbumName'
         self.ai.move(True)
-        self.lib.load(self.i)
+        self.ai.store()
+        self.i.load()
 
         self.assertTrue(os.path.exists(oldpath))
         self.assertTrue(os.path.exists(self.i.path))
 
     def test_albuminfo_move_to_custom_dir(self):
         self.ai.move(basedir=self.otherdir)
-        self.lib.load(self.i)
+        self.i.load()
+        self.ai.store()
         self.assertTrue('testotherdir' in self.i.path)
 
 class ArtFileTest(_common.TestCase):
@@ -205,8 +209,8 @@ class ArtFileTest(_common.TestCase):
         self.lib = beets.library.Library(':memory:')
         self.libdir = os.path.abspath(os.path.join(self.temp_dir, 'testlibdir'))
         self.lib.directory = self.libdir
-        self.i = item()
-        self.i.path = self.lib.destination(self.i)
+        self.i = item(self.lib)
+        self.i.path = self.i.destination()
         # Make a music file.
         util.mkdirall(self.i.path)
         touch(self.i.path)
@@ -216,6 +220,7 @@ class ArtFileTest(_common.TestCase):
         self.art = self.lib.get_album(self.i).art_destination('something.jpg')
         touch(self.art)
         self.ai.artpath = self.art
+        self.ai.store()
         # Alternate destination dir.
         self.otherdir = os.path.join(self.temp_dir, 'testotherdir')
 
@@ -229,7 +234,7 @@ class ArtFileTest(_common.TestCase):
         oldpath = self.i.path
         self.ai.album = 'newAlbum'
         self.ai.move()
-        self.lib.load(self.i)
+        self.i.load()
 
         self.assertNotEqual(self.i.path, oldpath)
         self.assertFalse(os.path.exists(self.art))
@@ -239,7 +244,8 @@ class ArtFileTest(_common.TestCase):
     def test_art_moves_with_album_to_custom_dir(self):
         # Move the album to another directory.
         self.ai.move(basedir=self.otherdir)
-        self.lib.load(self.i)
+        self.ai.store()
+        self.i.load()
 
         # Art should be in new directory.
         self.assertNotExists(self.art)
@@ -256,7 +262,7 @@ class ArtFileTest(_common.TestCase):
         i2.path = self.i.path
         i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
-        self.lib.move(i2, True)
+        i2.move(True)
 
         self.assertEqual(ai.artpath, None)
         ai.set_art(newart)
@@ -272,7 +278,7 @@ class ArtFileTest(_common.TestCase):
         i2.path = self.i.path
         i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
-        self.lib.move(i2, True)
+        i2.move(True)
         ai.set_art(newart)
 
         # Set the art again.
@@ -286,7 +292,7 @@ class ArtFileTest(_common.TestCase):
         i2.path = self.i.path
         i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
-        self.lib.move(i2, True)
+        i2.move(True)
 
         # Copy the art to the destination.
         artdest = ai.art_destination(newart)
@@ -303,7 +309,7 @@ class ArtFileTest(_common.TestCase):
         i2.path = self.i.path
         i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
-        self.lib.move(i2, True)
+        i2.move(True)
 
         # Make a file at the destination.
         artdest = ai.art_destination(newart)
@@ -327,7 +333,7 @@ class ArtFileTest(_common.TestCase):
             i2.path = self.i.path
             i2.artist = 'someArtist'
             ai = self.lib.add_album((i2,))
-            self.lib.move(i2, True)
+            i2.move(True)
             ai.set_art(newart)
 
             mode = stat.S_IMODE(os.stat(ai.artpath).st_mode)
@@ -344,7 +350,8 @@ class ArtFileTest(_common.TestCase):
         self.assertExists(oldartpath)
 
         self.ai.album = 'different_album'
-        self.lib.move(self.i)
+        self.ai.store()
+        self.ai.items()[0].move()
 
         artpath = self.lib.albums()[0].artpath
         self.assertTrue('different_album' in artpath)
@@ -361,7 +368,7 @@ class ArtFileTest(_common.TestCase):
 
         self.i.album = 'different_album'
         self.i.album_id = None # detach from album
-        self.lib.move(self.i)
+        self.i.move()
 
         artpath = self.lib.albums()[0].artpath
         self.assertFalse('different_album' in artpath)
@@ -376,8 +383,8 @@ class RemoveTest(_common.TestCase):
         self.lib = beets.library.Library(':memory:')
         self.libdir = os.path.abspath(os.path.join(self.temp_dir, 'testlibdir'))
         self.lib.directory = self.libdir
-        self.i = item()
-        self.i.path = self.lib.destination(self.i)
+        self.i = item(self.lib)
+        self.i.path = self.i.destination()
         # Make a music file.
         util.mkdirall(self.i.path)
         touch(self.i.path)
@@ -387,43 +394,44 @@ class RemoveTest(_common.TestCase):
     def test_removing_last_item_prunes_empty_dir(self):
         parent = os.path.dirname(self.i.path)
         self.assertExists(parent)
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertNotExists(parent)
 
     def test_removing_last_item_preserves_nonempty_dir(self):
         parent = os.path.dirname(self.i.path)
         touch(os.path.join(parent, 'dummy.txt'))
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertExists(parent)
 
     def test_removing_last_item_prunes_dir_with_blacklisted_file(self):
         parent = os.path.dirname(self.i.path)
         touch(os.path.join(parent, '.DS_Store'))
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertNotExists(parent)
 
     def test_removing_without_delete_leaves_file(self):
         path = self.i.path
-        self.lib.remove(self.i)
+        self.i.remove(False)
         self.assertExists(path)
 
     def test_removing_last_item_preserves_library_dir(self):
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertExists(self.libdir)
 
     def test_removing_item_outside_of_library_deletes_nothing(self):
         self.lib.directory = os.path.abspath(os.path.join(self.temp_dir, 'xxx'))
         parent = os.path.dirname(self.i.path)
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertExists(parent)
 
     def test_removing_last_item_in_album_with_albumart_prunes_dir(self):
         artfile = os.path.join(self.temp_dir, 'testart.jpg')
         touch(artfile)
         self.ai.set_art(artfile)
+        self.ai.store()
 
         parent = os.path.dirname(self.i.path)
-        self.lib.remove(self.i, True)
+        self.i.remove(True)
         self.assertNotExists(parent)
 
 # Tests that we can "delete" nonexistent files.
