@@ -14,17 +14,14 @@
 
 """Various tests for querying the library database.
 """
-import os
-
 import _common
 from _common import unittest
 import beets.library
 
 pqp = beets.library.parse_query_part
 
-some_item = _common.item()
 
-class QueryParseTest(unittest.TestCase):
+class QueryParseTest(_common.TestCase):
     def test_one_basic_term(self):
         q = 'test'
         r = (None, 'test', beets.library.SubstringQuery)
@@ -70,45 +67,64 @@ class QueryParseTest(unittest.TestCase):
         r = ('year', '1999..2010', beets.library.NumericQuery)
         self.assertEqual(pqp(q), r)
 
-class AnyFieldQueryTest(unittest.TestCase):
-    def setUp(self):
-        self.lib = beets.library.Library(':memory:')
-        self.lib.add(some_item)
 
+class AnyFieldQueryTest(_common.LibTestCase):
     def test_no_restriction(self):
         q = beets.library.AnyFieldQuery('title', beets.library.ITEM_KEYS,
                                         beets.library.SubstringQuery)
-        self.assertEqual(self.lib.items(q).next().title, 'the title')
+        self.assertEqual(self.lib.items(q).get().title, 'the title')
 
     def test_restriction_completeness(self):
         q = beets.library.AnyFieldQuery('title', ['title'],
                                         beets.library.SubstringQuery)
-        self.assertEqual(self.lib.items(q).next().title, 'the title')
+        self.assertEqual(self.lib.items(q).get().title, 'the title')
 
     def test_restriction_soundness(self):
         q = beets.library.AnyFieldQuery('title', ['artist'],
                                         beets.library.SubstringQuery)
-        self.assertRaises(StopIteration, self.lib.items(q).next)
+        self.assertEqual(self.lib.items(q).get(), None)
+
 
-# Convenient asserts for matching items.
 class AssertsMixin(object):
-    def assert_matched(self, result_iterator, title):
-        self.assertEqual(result_iterator.next().title, title)
-    def assert_done(self, result_iterator):
-        self.assertRaises(StopIteration, result_iterator.next)
-    def assert_matched_all(self, result_iterator):
-        self.assert_matched(result_iterator, 'Littlest Things')
-        self.assert_matched(result_iterator, 'Take Pills')
-        self.assert_matched(result_iterator, 'Lovers Who Uncover')
-        self.assert_matched(result_iterator, 'Boracay')
-        self.assert_done(result_iterator)
+    def assert_matched(self, results, titles):
+        self.assertEqual([i.title for i in results], titles)
 
-class GetTest(unittest.TestCase, AssertsMixin):
+
+# A test case class providing a library with some dummy data and some
+# assertions involving that data.
+class DummyDataTestCase(_common.TestCase, AssertsMixin):
     def setUp(self):
-        self.lib = beets.library.Library(
-            os.path.join(_common.RSRC, 'test.blb')
-        )
+        super(DummyDataTestCase, self).setUp()
+        self.lib = beets.library.Library(':memory:')
+        items = [_common.item() for _ in range(3)]
+        items[0].title = 'foo bar'
+        items[0].artist = 'one'
+        items[0].album = 'baz'
+        items[0].year = 2001
+        items[0].comp = True
+        items[1].title = 'baz qux'
+        items[1].artist = 'two'
+        items[1].album = 'baz'
+        items[1].year = 2002
+        items[1].comp = True
+        items[2].title = 'beets 4 eva'
+        items[2].artist = 'three'
+        items[2].album = 'foo'
+        items[2].year = 2003
+        items[2].comp = False
+        for item in items:
+            self.lib.add(item)
+        self.lib.add_album(items[:2])
 
+    def assert_matched_all(self, results):
+        self.assert_matched(results, [
+            'foo bar',
+            'baz qux',
+            'beets 4 eva',
+        ])
+
+
+class GetTest(DummyDataTestCase):
     def test_get_empty(self):
         q = ''
         results = self.lib.items(q)
@@ -120,201 +136,183 @@ class GetTest(unittest.TestCase, AssertsMixin):
         self.assert_matched_all(results)
 
     def test_get_one_keyed_term(self):
-        q = 'artist:Lil'
+        q = 'title:qux'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_done(results)
+        self.assert_matched(results, ['baz qux'])
 
     def test_get_one_keyed_regexp(self):
-        q = r'artist::L.+y'
+        q = r'artist::t.+r'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
     def test_get_one_unkeyed_term(self):
-        q = 'Terry'
+        q = 'three'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
     def test_get_one_unkeyed_regexp(self):
-        q = r':y$'
+        q = r':x$'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, ['baz qux'])
 
     def test_get_no_matches(self):
         q = 'popebear'
         results = self.lib.items(q)
-        self.assert_done(results)
+        self.assert_matched(results, [])
 
     def test_invalid_key(self):
         q = 'pope:bear'
         results = self.lib.items(q)
-        self.assert_matched_all(results)
+        # Matches nothing since the flexattr is not present on the
+        # objects.
+        self.assert_matched(results, [])
 
     def test_term_case_insensitive(self):
-        q = 'UNCoVER'
+        q = 'oNE'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, ['foo bar'])
 
     def test_regexp_case_sensitive(self):
-        q = r':UNCoVER'
+        q = r':oNE'
         results = self.lib.items(q)
-        self.assert_done(results)
-        q = r':Uncover'
+        self.assert_matched(results, [])
+        q = r':one'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, ['foo bar'])
 
     def test_term_case_insensitive_with_key(self):
-        q = 'album:stiLL'
+        q = 'artist:thrEE'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
     def test_key_case_insensitive(self):
-        q = 'ArTiST:Allen'
+        q = 'ArTiST:three'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
     def test_unkeyed_term_matches_multiple_columns(self):
-        q = 'little'
+        q = 'baz'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, [
+            'foo bar',
+            'baz qux',
+        ])
 
     def test_unkeyed_regexp_matches_multiple_columns(self):
-        q = r':^T'
+        q = r':z$'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Take Pills')
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, [
+            'foo bar',
+            'baz qux',
+        ])
 
     def test_keyed_term_matches_only_one_column(self):
-        q = 'artist:little'
+        q = 'title:baz'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, ['baz qux'])
 
     def test_keyed_regexp_matches_only_one_column(self):
-        q = r'album::\sS'
+        q = r'title::baz'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, [
+            'baz qux',
+        ])
 
     def test_multiple_terms_narrow_search(self):
-        q = 'little ones'
+        q = 'qux baz'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_matched(results, 'Boracay')
-        self.assert_done(results)
+        self.assert_matched(results, [
+            'baz qux',
+        ])
 
     def test_multiple_regexps_narrow_search(self):
-        q = r':\sS :^T'
+        q = r':baz :qux'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, ['baz qux'])
 
     def test_mixed_terms_regexps_narrow_search(self):
-        q = r':\sS lily'
+        q = r':baz qux'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_done(results)
+        self.assert_matched(results, ['baz qux'])
 
     def test_single_year(self):
-        q = 'year:2006'
+        q = 'year:2001'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, ['foo bar'])
 
     def test_year_range(self):
-        q = 'year:2000..2010'
+        q = 'year:2000..2002'
         results = self.lib.items(q)
-        self.assert_matched(results, 'Littlest Things')
-        self.assert_matched(results, 'Take Pills')
-        self.assert_matched(results, 'Lovers Who Uncover')
-        self.assert_done(results)
+        self.assert_matched(results, [
+            'foo bar',
+            'baz qux',
+        ])
 
     def test_bad_year(self):
         q = 'year:delete from items'
         self.assertRaises(ValueError, self.lib.items, q)
 
-class MemoryGetTest(unittest.TestCase, AssertsMixin):
-    def setUp(self):
-        self.album_item = _common.item()
-        self.album_item.title = 'album item'
-        self.single_item = _common.item()
-        self.single_item.title = 'singleton item'
-        self.single_item.comp = False
-
-        self.lib = beets.library.Library(':memory:')
-        self.lib.add(self.single_item)
-        self.album = self.lib.add_album([self.album_item])
-
     def test_singleton_true(self):
         q = 'singleton:true'
         results = self.lib.items(q)
-        self.assert_matched(results, 'singleton item')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
     def test_singleton_false(self):
         q = 'singleton:false'
         results = self.lib.items(q)
-        self.assert_matched(results, 'album item')
-        self.assert_done(results)
+        self.assert_matched(results, ['foo bar', 'baz qux'])
 
     def test_compilation_true(self):
         q = 'comp:true'
         results = self.lib.items(q)
-        self.assert_matched(results, 'album item')
-        self.assert_done(results)
+        self.assert_matched(results, ['foo bar', 'baz qux'])
 
     def test_compilation_false(self):
         q = 'comp:false'
         results = self.lib.items(q)
-        self.assert_matched(results, 'singleton item')
-        self.assert_done(results)
+        self.assert_matched(results, ['beets 4 eva'])
 
-    def test_unknown_field_name_ignored(self):
+    def test_unknown_field_name_no_results(self):
         q = 'xyzzy:nonsense'
         results = self.lib.items(q)
         titles = [i.title for i in results]
-        self.assertTrue('singleton item' in titles)
-        self.assertTrue('album item' in titles)
-        self.assertEqual(len(titles), 2)
+        self.assertEqual(titles, [])
 
-    def test_unknown_field_name_ignored_in_album_query(self):
+    def test_unknown_field_name_no_results_in_album_query(self):
         q = 'xyzzy:nonsense'
         results = self.lib.albums(q)
         names = [a.album for a in results]
-        self.assertEqual(names, ['the album'])
+        self.assertEqual(names, [])
 
-    def test_item_field_name_ignored_in_album_query(self):
+    def test_item_field_name_matches_nothing_in_album_query(self):
         q = 'format:nonsense'
         results = self.lib.albums(q)
         names = [a.album for a in results]
-        self.assertEqual(names, ['the album'])
+        self.assertEqual(names, [])
 
     def test_unicode_query(self):
-        self.single_item.title = u'caf\xe9'
-        self.lib.store(self.single_item)
+        item = self.lib.items().get()
+        item.title = u'caf\xe9'
+        item.store()
 
         q = u'title:caf\xe9'
         results = self.lib.items(q)
-        self.assert_matched(results, u'caf\xe9')
-        self.assert_done(results)
+        self.assert_matched(results, [u'caf\xe9'])
 
-class MatchTest(unittest.TestCase):
+    def test_numeric_search_positive(self):
+        q = beets.library.NumericQuery('year', '2001')
+        results = self.lib.items(q)
+        self.assertTrue(results)
+
+    def test_numeric_search_negative(self):
+        q = beets.library.NumericQuery('year', '1999')
+        results = self.lib.items(q)
+        self.assertFalse(results)
+
+
+class MatchTest(_common.TestCase):
     def setUp(self):
+        super(MatchTest, self).setUp()
         self.item = _common.item()
 
     def test_regex_match_positive(self):
@@ -357,124 +355,84 @@ class MatchTest(unittest.TestCase):
         q = beets.library.NumericQuery('bitrate', '200000..300000')
         self.assertFalse(q.match(self.item))
 
-class PathQueryTest(unittest.TestCase, AssertsMixin):
-    def setUp(self):
-        self.lib = beets.library.Library(':memory:')
 
-        path_item = _common.item()
-        path_item.path = '/a/b/c.mp3'
-        path_item.title = 'path item'
-        self.lib.add(path_item)
+class PathQueryTest(_common.LibTestCase, AssertsMixin):
+    def setUp(self):
+        super(PathQueryTest, self).setUp()
+        self.i.path = '/a/b/c.mp3'
+        self.i.title = 'path item'
+        self.i.store()
 
     def test_path_exact_match(self):
         q = 'path:/a/b/c.mp3'
         results = self.lib.items(q)
-        self.assert_matched(results, 'path item')
-        self.assert_done(results)
+        self.assert_matched(results, ['path item'])
 
     def test_parent_directory_no_slash(self):
         q = 'path:/a'
         results = self.lib.items(q)
-        self.assert_matched(results, 'path item')
-        self.assert_done(results)
+        self.assert_matched(results, ['path item'])
 
     def test_parent_directory_with_slash(self):
         q = 'path:/a/'
         results = self.lib.items(q)
-        self.assert_matched(results, 'path item')
-        self.assert_done(results)
+        self.assert_matched(results, ['path item'])
 
     def test_no_match(self):
         q = 'path:/xyzzy/'
         results = self.lib.items(q)
-        self.assert_done(results)
+        self.assert_matched(results, [])
 
     def test_fragment_no_match(self):
         q = 'path:/b/'
         results = self.lib.items(q)
-        self.assert_done(results)
+        self.assert_matched(results, [])
 
     def test_nonnorm_path(self):
         q = 'path:/x/../a/b'
         results = self.lib.items(q)
-        self.assert_matched(results, 'path item')
-        self.assert_done(results)
+        self.assert_matched(results, ['path item'])
 
     def test_slashed_query_matches_path(self):
         q = '/a/b'
         results = self.lib.items(q)
-        self.assert_matched(results, 'path item')
-        self.assert_done(results)
+        self.assert_matched(results, ['path item'])
 
     def test_non_slashed_does_not_match_path(self):
         q = 'c.mp3'
         results = self.lib.items(q)
-        self.assert_done(results)
+        self.assert_matched(results, [])
 
     def test_slashes_in_explicit_field_does_not_match_path(self):
         q = 'title:/a/b'
         results = self.lib.items(q)
-        self.assert_done(results)
+        self.assert_matched(results, [])
 
-class BrowseTest(unittest.TestCase, AssertsMixin):
-    def setUp(self):
-        self.lib = beets.library.Library(
-            os.path.join(_common.RSRC, 'test.blb')
-        )
+    def test_path_regex(self):
+        q = 'path::\\.mp3$'
+        results = self.lib.items(q)
+        self.assert_matched(results, ['path item'])
 
-    def test_album_list(self):
-        albums = list(self.lib.albums())
-        album_names = [a.album for a in albums]
-        for aname in ['Alright, Still', 'Person Pitch', 'Sing Song',
-                      'Terry Tales & Fallen Gates EP']:
-            self.assert_(aname in album_names)
-        self.assertEqual(len(albums), 4)
-
-    def test_item_list(self):
-        items = self.lib.items()
-        self.assert_matched(items, 'Littlest Things')
-        self.assert_matched(items, 'Take Pills')
-        self.assert_matched(items, 'Lovers Who Uncover')
-        self.assert_matched(items, 'Boracay')
-        self.assert_done(items)
 
+class DefaultSearchFieldsTest(DummyDataTestCase):
     def test_albums_matches_album(self):
-        albums = list(self.lib.albums('person'))
+        albums = list(self.lib.albums('baz'))
         self.assertEqual(len(albums), 1)
 
     def test_albums_matches_albumartist(self):
-        albums = list(self.lib.albums('panda'))
+        albums = list(self.lib.albums(['album artist']))
         self.assertEqual(len(albums), 1)
 
     def test_items_matches_title(self):
-        items = self.lib.items('boracay')
-        self.assert_matched(items, 'Boracay')
-        self.assert_done(items)
+        items = self.lib.items('beets')
+        self.assert_matched(items, ['beets 4 eva'])
 
     def test_items_does_not_match_year(self):
-        items = self.lib.items('2007')
-        self.assert_done(items)
+        items = self.lib.items('2001')
+        self.assert_matched(items, [])
 
-class CountTest(unittest.TestCase):
-    def setUp(self):
-        self.lib = beets.library.Library(':memory:')
-        self.item = some_item
-        self.lib.add(self.item)
 
-    def test_count_gets_single_item(self):
-        with self.lib.transaction() as tx:
-            songs, totaltime = beets.library.TrueQuery().count(tx)
-        self.assertEqual(songs, 1)
-        self.assertEqual(totaltime, self.item.length)
-
-    def test_count_works_for_empty_library(self):
-        self.lib.remove(self.item)
-        with self.lib.transaction() as tx:
-            songs, totaltime = beets.library.TrueQuery().count(tx)
-        self.assertEqual(songs, 0)
-        self.assertEqual(totaltime, 0.0)
-
-class StringParseTest(unittest.TestCase):
+class StringParseTest(_common.TestCase):
     def test_single_field_query(self):
         q = beets.library.AndQuery.from_string(u'albumtype:soundtrack')
         self.assertEqual(len(q.subqueries), 1)
@@ -483,8 +441,10 @@ class StringParseTest(unittest.TestCase):
         self.assertEqual(subq.field, 'albumtype')
         self.assertEqual(subq.pattern, 'soundtrack')
 
+
 def suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
 
+
 if __name__ == '__main__':
     unittest.main(defaultTest='suite')
