@@ -17,7 +17,6 @@
 import os
 import shutil
 import textwrap
-import logging
 import re
 import yaml
 
@@ -55,7 +54,7 @@ class ListTest(_common.TestCase):
 
     def test_list_unicode_query(self):
         self.item.title = u'na\xefve'
-        self.lib.store(self.item)
+        self.item.store()
         self.lib._connection().commit()
 
         self._run_list([u'na\xefve'])
@@ -125,7 +124,8 @@ class RemoveTest(_common.TestCase):
         # Copy a file into the library.
         self.lib = library.Library(':memory:', self.libdir)
         self.i = library.Item.from_path(os.path.join(_common.RSRC, 'full.mp3'))
-        self.lib.add(self.i, True)
+        self.lib.add(self.i)
+        self.i.move(True)
 
     def test_remove_items_no_delete(self):
         self.io.addinput('y')
@@ -152,7 +152,8 @@ class ModifyTest(_common.TestCase):
         # Copy a file into the library.
         self.lib = library.Library(':memory:', self.libdir)
         self.i = library.Item.from_path(os.path.join(_common.RSRC, 'full.mp3'))
-        self.lib.add(self.i, True)
+        self.lib.add(self.i)
+        self.i.move(True)
         self.album = self.lib.add_album([self.i])
 
     def _modify(self, mods, query=(), write=False, move=False, album=False):
@@ -162,7 +163,7 @@ class ModifyTest(_common.TestCase):
 
     def test_modify_item_dbdata(self):
         self._modify(["title=newTitle"])
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertEqual(item.title, 'newTitle')
 
     def test_modify_album_dbdata(self):
@@ -172,47 +173,47 @@ class ModifyTest(_common.TestCase):
 
     def test_modify_item_tag_unmodified(self):
         self._modify(["title=newTitle"], write=False)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertEqual(item.title, 'full')
 
     def test_modify_album_tag_unmodified(self):
         self._modify(["album=newAlbum"], write=False, album=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertEqual(item.album, 'the album')
 
     def test_modify_item_tag(self):
         self._modify(["title=newTitle"], write=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertEqual(item.title, 'newTitle')
 
     def test_modify_album_tag(self):
         self._modify(["album=newAlbum"], write=True, album=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertEqual(item.album, 'newAlbum')
 
     def test_item_move(self):
         self._modify(["title=newTitle"], move=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertTrue('newTitle' in item.path)
 
     def test_album_move(self):
         self._modify(["album=newAlbum"], move=True, album=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertTrue('newAlbum' in item.path)
 
     def test_item_not_move(self):
         self._modify(["title=newTitle"], move=False)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertFalse('newTitle' in item.path)
 
     def test_album_not_move(self):
         self._modify(["album=newAlbum"], move=False, album=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         item.read()
         self.assertFalse('newAlbum' in item.path)
 
@@ -231,7 +232,7 @@ class MoveTest(_common.TestCase):
         # Add a file to the library but don't copy it in yet.
         self.lib = library.Library(':memory:', self.libdir)
         self.i = library.Item.from_path(self.itempath)
-        self.lib.add(self.i, False)
+        self.lib.add(self.i)
         self.album = self.lib.add_album([self.i])
 
         # Alternate destination directory.
@@ -242,42 +243,42 @@ class MoveTest(_common.TestCase):
 
     def test_move_item(self):
         self._move()
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testlibdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertNotExists(self.itempath)
 
     def test_copy_item(self):
         self._move(copy=True)
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testlibdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertExists(self.itempath)
 
     def test_move_album(self):
         self._move(album=True)
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testlibdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertNotExists(self.itempath)
 
     def test_copy_album(self):
         self._move(copy=True, album=True)
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testlibdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertExists(self.itempath)
 
     def test_move_item_custom_dir(self):
         self._move(dest=self.otherdir)
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testotherdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertNotExists(self.itempath)
 
     def test_move_album_custom_dir(self):
         self._move(dest=self.otherdir, album=True)
-        self.lib.load(self.i)
+        self.i.load()
         self.assertTrue('testotherdir' in self.i.path)
         self.assertExists(self.i.path)
         self.assertNotExists(self.itempath)
@@ -293,20 +294,22 @@ class UpdateTest(_common.TestCase):
         # Copy a file into the library.
         self.lib = library.Library(':memory:', self.libdir)
         self.i = library.Item.from_path(os.path.join(_common.RSRC, 'full.mp3'))
-        self.lib.add(self.i, True)
+        self.lib.add(self.i)
+        self.i.move(True)
         self.album = self.lib.add_album([self.i])
 
         # Album art.
         artfile = os.path.join(_common.RSRC, 'testart.jpg')
         _common.touch(artfile)
         self.album.set_art(artfile)
+        self.album.store()
         os.remove(artfile)
 
     def _update(self, query=(), album=False, move=False, reset_mtime=True):
         self.io.addinput('y')
         if reset_mtime:
             self.i.mtime = 0
-            self.lib.store(self.i)
+            self.i.store()
         commands.update_items(self.lib, query, album, move, False)
 
     def test_delete_removes_item(self):
@@ -333,7 +336,7 @@ class UpdateTest(_common.TestCase):
         mf.title = 'differentTitle'
         mf.save()
         self._update()
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertEqual(item.title, 'differentTitle')
 
     def test_modified_metadata_moved(self):
@@ -341,7 +344,7 @@ class UpdateTest(_common.TestCase):
         mf.title = 'differentTitle'
         mf.save()
         self._update(move=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertTrue('differentTitle' in item.path)
 
     def test_modified_metadata_not_moved(self):
@@ -349,7 +352,7 @@ class UpdateTest(_common.TestCase):
         mf.title = 'differentTitle'
         mf.save()
         self._update(move=False)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertTrue('differentTitle' not in item.path)
 
     def test_modified_album_metadata_moved(self):
@@ -357,7 +360,7 @@ class UpdateTest(_common.TestCase):
         mf.album = 'differentAlbum'
         mf.save()
         self._update(move=True)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertTrue('differentAlbum' in item.path)
 
     def test_modified_album_metadata_art_moved(self):
@@ -376,10 +379,10 @@ class UpdateTest(_common.TestCase):
 
         # Make in-memory mtime match on-disk mtime.
         self.i.mtime = os.path.getmtime(self.i.path)
-        self.lib.store(self.i)
+        self.i.store()
 
         self._update(reset_mtime=False)
-        item = self.lib.items().next()
+        item = self.lib.items().get()
         self.assertEqual(item.title, 'full')
 
 class PrintTest(_common.TestCase):
