@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 # This file is part of beets.
-# Copyright 2010, Adrian Sampson.
+# Copyright 2013, Adrian Sampson.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -24,6 +24,13 @@ pkgpath = os.path.dirname(__file__) or '.'
 sys.path.append(pkgpath)
 os.chdir(pkgpath)
 
+# Make sure we use local version of beetsplug and not system namespaced version
+# for tests
+try:
+    del sys.modules["beetsplug"]
+except KeyError:
+    pass
+
 def suite():
     s = unittest.TestSuite()
     # Get the suite() of every module in this directory beginning with
